Prov.Anomalies<-function(recipe,data,graph, type){
  #Define parentnodename
  i<-switch(type,
            "fcst"="parentnodename_fcst",
            "hcst"="parentnodename_hcst",
            "obs"="parentnodename_obs")
  parentnodename<-graph$parentnodename[[i]]
  graph<-graph$graph
  dc.description="Anomaly calculation in climatology involves subtracting a climatological baseline from observed or modeled data to isolate deviations from the average conditions. 
                  This process, often augmented by cross-validation techniques, allows for the identification and analysis of unusual or abnormal climate patterns.For more details, see the  CSTools documentation for CST_Anomaly()"
  referenceURL<-"https://cran.r-project.org/web/packages/CSTools/CSTools.pdf"
  if(recipe$Analysis$Workflow$Anomalies$compute){
    
    if(type=="obs" | type=="hcst"){
        #Climatology calculation
        clim.nodename<-paste0("Climatology_",type)
        graph <- add_vertices(graph,
                              nv = 1,
                              name = clim.nodename,
                              label = "Climatology",
                              className = "ds:Climatology"
                              )

        graph <- add_edges(graph, 
                          c(getNodeIndexbyName(graph, parentnodename),
                            getNodeIndexbyName(graph, clim.nodename)),
                          label = "ds:hadClimatology")
    }else{
      clim.nodename<-"Climatology_hcst"
      graph <- add_vertices(graph,
                            nv = 1,
                            name = clim.nodename,
                            label = "Climatology",
                            className = "ds:Climatology"
      )
    }                 
    
    #Anomaly calculation
    anom.nodename<-paste0("Anomalies_",type)
    if(recipe$Analysis$Workflow$Anomalies$cross_validation){
      comment="Cross-validation computed. Cross-validation enhances the robustness of anomaly calculations by validating the chosen baseline against independent datasets, ensuring greater reliability in assessing climate variability and change. 
              Anomalies thus derived are valuable for assessing trends, detecting extremes, and informing decision-making in various fields such as agriculture, water resource management, and disaster preparedness."

      graph <- add_vertices(graph,
                              nv = 1,
                              name = anom.nodename,
                              label = "Anomaly",
                              className = "ds:Anomaly",
                              attr = list("dc:description" = dc.description,
                              "dc:comment"=comment,
                              "ds:referenceURL"=referenceURL
                              ))
    }else{
      graph <- add_vertices(graph,
                            nv = 1,
                            name = anom.nodename,
                            label = "Anomaly",
                            className = "ds:Anomaly",
                            attr = list("dc:description" = dc.description,
                            "ds:referenceURL"=referenceURL
                            ))        
      }
    graph <- add_edges(graph,
                      c(getNodeIndexbyName(graph, parentnodename),
                      getNodeIndexbyName(graph, anom.nodename)),
                      label = "ds:hadAnomalyCalculation")  

    graph <- add_edges(graph,
                      c(getNodeIndexbyName(graph, anom.nodename),
                        getNodeIndexbyName(graph, clim.nodename)),
                      label = "ds:withReference")
    
    print(paste0("Anomalies provenance computed for ",type))
    return(list("graph"=graph, "parentnodename"=anom.nodename))
  }else{
    return(list("graph"=graph$graph, "parentnodename"=parentnodename))
  }
  
}