Prov.Calibration<-function(recipe,data,graph,type){
  #Define Calibration parameters
  cal<-tolower(recipe$Analysis$Workflow$Calibration$method)
  archive<-read_yaml("conf/variable-dictionary_provenance.yml")
  if(cal %in% names(archive$calibration)){
    cal.method<-archive$calibration[[cal]]$long_name
    cal.class<-paste0("cal:",archive$calibration[[cal]]$representation)
    cal.description<-archive$calibration[[cal]]$definition
  }else{
    stop("Calibration method not registered or not properly defined")
  }

  if(!(cal=="qmap")){
    comment="For more details, see the  CSTools documentation for CST_Calibration()"
  }else{
    comment="For more details, see the  CSTools documentation for CST_QuantileMapping()"
  }
  referenceURL="https://cran.r-project.org/web/packages/CSTools/CSTools.pdf"
  reference.nodename<-graph$parentnodename$parentnodename_obs

  #Define last node to which Calibration is applied
  if(type=="fcst" | type=="hcst"){
    i<-switch(type,
            "fcst"="parentnodename_fcst",
            "hcst"="parentnodename_hcst")
    parentnodename<-graph$parentnodename[[i]]
    graph<-graph$graph

    #Add Calibration node and vertex
    cal.nodename<-paste0("Calibration_",type)
    graph <- my_add_vertices(graph,
                             name = cal.nodename,
                             label = "Calibration",
                             className = "cal:Calibration")
    graph <- add_edges(graph, 
                       c(getNodeIndexbyName(graph, parentnodename),
                         getNodeIndexbyName(graph, cal.nodename)),
                       label = "cal:hadCalibration")
    
    #Update SpatialExtent
    refgraph<-getSpatialExtent(data, type, Cal=TRUE)
    graph <- my_union_graph(graph, refgraph$graph)
    graph <- add_edges(graph,
                       c(getNodeIndexbyName(graph, cal.nodename),
                         getNodeIndexbyName(graph, refgraph$parentnodename)),
                       label = "ds:hasHorizontalExtent")    

    #Adding Calibration Method
    calmethod.nodename<-paste0("CalibrationMethod_","all")
    graph <- my_add_vertices(graph,
                             name = calmethod.nodename,
                             label = cal.method,
                             className = cal.class,
                             attr=list("dc:description"=cal.description,
                             "dc:comment"=comment,
                             "ds:referenceURL"=referenceURL)
                             )
    graph <- add_edges(graph, 
                       c(getNodeIndexbyName(graph, cal.nodename),
                         getNodeIndexbyName(graph, calmethod.nodename)),
                       label = "cal:withCalibrationMethod")
    
    #Reference node
    graph <- add_edges(graph, 
                       c(getNodeIndexbyName(graph, cal.nodename),
                         getNodeIndexbyName(graph, reference.nodename)),
                       label = "cal:withReferenceData")

  print(paste0("Calibration provenance computed for ", type))
  
    return(list("graph"=graph, "parentnodename"=cal.nodename))
  }else{
    return(list("graph"=graph$graph, "parentnodename"=graph$parentnodename$parentnodename_obs))
  }
  
}